@@ -10,7 +10,8 @@ class mustafa:
     votingalgos = dict()
     atype = ""
     parameters = 0
-    def __init__(m, precision=1, maxattrs="max",atype="",selection=[],hyperstep=1):
+    stats = None
+    def __init__(m, precision=1, maxattrs="max",atype="",selection=[],hyperstep=1,stats=False):
         dictionaries = dict()
         import sklearn
         import inspect
@@ -23,6 +24,7 @@ class mustafa:
         m.selection = selection
         m.alldict = dict()
         m.dictclasses = dict()
+        m.stats = stats
         #print(precision,atype,maxattrs,selection)
         categories = [sklearn.svm,sklearn.neural_network,sklearn.tree,sklearn.neighbors,sklearn.naive_bayes,sklearn.ensemble]
         
@@ -232,6 +234,12 @@ class mustafa:
                         #m.listall(p=True)
         #print(m.parameters)
         m.listall(p=True)
+        print()
+        if m.stats:
+            print("Thank you for opting in to share your results to improve {mustafa} :)")
+        else:
+            print("Feel free to share your training results to improve {mustafa} by setting (stats=True) in the constructor :)")
+
 
 
     def listall(m,p=False):
@@ -265,8 +273,9 @@ class mustafa:
         from sklearn.metrics import accuracy_score, confusion_matrix, roc_auc_score, roc_curve, cohen_kappa_score, f1_score, recall_score, precision_score
         import datetime
         if estimate != 1:
+            oldx = X
             X, _, y, _ = train_test_split(X, y, train_size=estimate, random_state=42)
-            print("Estimating on ",estimate," of the dataset")
+            print("Estimating on ",round(len(oldx)*estimate),"(",estimate*100,"%) records out of ",len(oldx))
         def measures(predicted, y_test):
             print()
             metrics = dict()
@@ -326,10 +335,33 @@ class mustafa:
                 difference = divmod(elapsedTime.total_seconds(), 60)
                 timing = str("Time elapsed: {0} minutes ({1} seconds)".format(difference[0],difference[1]))
                 m.trainings[str(modelname)+"@"+str(datetime.datetime.now())] = timing
-
+                recordscount = str(len(X))
+                if estimate != 1:
+                    recordscount = str(round(len(X)*estimate))
+                    estimate = 1
+                else:
+                    estimate = 0
+                if m.stats:
+                    import requests
+                    data={'name': str(modelname),
+                          'accuracy': str(gridsearches[model]['accuracy']),
+                          'precision':str(gridsearches[model]['precision']),
+                          'recall':str(gridsearches[model]['recall']),
+                          'f1':str(gridsearches[model]['f1']),
+                          'records_count': recordscount,
+                          'attributes_count': str(X.shape[1]),
+                          'hyperparameters': str(model),
+                          'training_time':str(difference[0]*60.0+difference[1]),
+                          'estimated':estimate
+                          }
+                    res = requests.post('https://mustafasa.com/op/trainings.php', data)
             except Exception as e:
                 print(str(e)+" algorithm skipped")
             m.latesttraining = gridsearches
+            if m.stats:
+                print("Thank you for opting in to share your results to improve {mustafa} :)")
+            else:
+                print("Feel free to share your training results to improve {mustafa} by setting (stats=True) in the constructor :)")
         return gridsearches
     def best(m,rs=[]):
         mustafa(m,rs)
